@@ -258,34 +258,35 @@ public final class NioDatagramAcceptor extends AbstractIoAcceptor implements Dat
     }
 
     private void processReadySessions(Set<SelectionKey> handles) {
-	final Iterator<SelectionKey> iterator = handles.iterator();
+        final Iterator<SelectionKey> iterator = handles.iterator();
 
-	while (iterator.hasNext()) {
-	    try {
-		final SelectionKey key = iterator.next();
-		final DatagramChannel handle = (DatagramChannel) key.channel();
+        while (iterator.hasNext()) {
+            try {
+                SelectionKey key = iterator.next();
+                DatagramChannel handle = (DatagramChannel) key.channel();
+    
+                if (key.isValid()) {
+                    if (key.isReadable()) {
+                        readHandle(handle);
+                    }
+    
+                    if (key.isWritable()) {
+                        for (IoSession session : getManagedSessions().values()) {
+                            NioSession nioSession = (NioSession) session;
+                            
+                            if (nioSession.getChannel() == handle) {
+                                scheduleFlush(nioSession);
+                            }
+                    }
+                }
+            }
 
-		if (key.isValid()) {
-		    if (key.isReadable()) {
-			readHandle(handle);
-		    }
-
-		    if (key.isWritable()) {
-			for (IoSession session : getManagedSessions().values()) {
-			    final NioSession x = (NioSession) session;
-			    if (x.getChannel() == handle) {
-				scheduleFlush(x);
-			    }
-			}
-		    }
-		}
-
-	    } catch (Exception e) {
-		ExceptionMonitor.getInstance().exceptionCaught(e);
-	    } finally {
-		iterator.remove();
-	    }
-	}
+            } catch (Exception e) {
+                ExceptionMonitor.getInstance().exceptionCaught(e);
+            } finally {
+                iterator.remove();
+            }
+        }
     }
 
     private boolean scheduleFlush(NioSession session) {
